@@ -1,18 +1,43 @@
 use strict;
 use warnings;
 package Getopt::Long::Descriptive::Usage;
-{
-  $Getopt::Long::Descriptive::Usage::VERSION = '0.096';
-}
 # ABSTRACT: the usage description for GLD
-
+$Getopt::Long::Descriptive::Usage::VERSION = '0.097';
 use List::Util qw(max);
 
+# =head1 SYNOPSIS
+#
+#   use Getopt::Long::Descriptive;
+#   my ($opt, $usage) = describe_options( ... );
+#
+#   $usage->text; # complete usage message
+#
+#   $usage->die;  # die with usage message
+#
+# =head1 DESCRIPTION
+#
+# This document only describes the methods of the Usage object.  For information
+# on how to use L<Getopt::Long::Descriptive>, consult its documentation.
+#
+# =head1 METHODS
+#
+# =head2 new
+#
+#   my $usage = Getopt::Long::Descriptive::Usage->new(\%arg);
+#
+# You B<really> don't need to call this.  GLD will do it for you.
+#
+# Valid arguments are:
+#
+#   options     - an arrayref of options
+#   leader_text - the text that leads the usage; this may go away!
+#
+# =cut
 
 sub new {
   my ($class, $arg) = @_;
 
-  my @to_copy = qw(options leader_text);
+  my @to_copy = qw(options leader_text show_defaults);
 
   my %copy;
   @copy{ @to_copy } = @$arg{ @to_copy };
@@ -20,6 +45,11 @@ sub new {
   bless \%copy => $class;
 }
 
+# =head2 text
+#
+# This returns the full text of the usage message.
+#
+# =cut
 
 sub text {
   my ($self) = @_;
@@ -27,9 +57,19 @@ sub text {
   return join qq{\n}, $self->leader_text, $self->option_text;
 }
 
+# =head2 leader_text
+#
+# This returns the text that comes at the beginning of the usage message.
+#
+# =cut
 
 sub leader_text { $_[0]->{leader_text} }
 
+# =head2 option_text
+#
+# This returns the text describing the available options.
+#
+# =cut
 
 sub option_text {
   my ($self) = @_;
@@ -58,6 +98,12 @@ sub option_text {
 
     my @desc = $self->_split_description($length, $desc);
 
+    # add default value if it exists
+    if ( $opt->{constraint}->{default} and $self->{show_defaults}) {
+      my $dflt = $opt->{constraint}->{default};
+      push @desc, "(default value: $dflt)";
+    }
+
     $string .= sprintf "$spec_fmt  %s\n", $spec, shift @desc;
     for my $line (@desc) {
         $string .= "\t";
@@ -89,9 +135,29 @@ sub _split_description {
   return @lines;
 }
 
+# =head2 warn
+#
+# This warns with the usage message.
+#
+# =cut
 
 sub warn { warn shift->text }
 
+# =head2 die
+#
+# This throws the usage message as an exception.
+#
+#   $usage_obj->die(\%arg);
+#
+# Some arguments can be provided 
+#
+#   pre_text  - text to be prepended to the usage message
+#   post_text - text to be appended to the usage message
+#
+# The C<pre_text> and C<post_text> arguments are concatenated with the usage
+# message with no line breaks, so supply this if you need them.
+#
+# =cut
 
 sub die  {
   my $self = shift;
@@ -120,13 +186,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Getopt::Long::Descriptive::Usage - the usage description for GLD
 
 =head1 VERSION
 
-version 0.096
+version 0.097
 
 =head1 SYNOPSIS
 
